@@ -8,7 +8,7 @@ VarExpl.lcmm <- function(x,values)
  if(any(is.na(values))) stop("values should not contain any missing values")
 
 
- if(x$conv==1 | x$conv==2)
+ if(x$conv==1 | x$conv==2 | x$conv==3)
  {
    
   
