@@ -65,6 +65,23 @@ if(x$conv==1 | x$conv==2 | x$conv==3)
      }
     }
    }
+
+  ## pour poly()
+  if(any(grep("poly",termes)))
+      {
+          split_termes <- strsplit(termes,split="")
+          for(j in 1:length(split_termes))
+              {
+                  splitj <- split_termes[[j]]
+                  
+                  if(paste(splitj[c(1:5,length(splitj)-1)],collapse="")=="poly()")
+                      {
+                          termes[j] <- paste(splitj[1:(length(splitj)-1)],collapse="")
+                      }
+
+              }
+              
+      }
   
   
   ## var.time
